@@ -19,7 +19,7 @@ class VUFR:
             "user-agent": "Mozilla/5.0 (Linux; Android 10; Infinix X657C) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/101.0.4951.40 Mobile Safari/537.36",
             "x-requested-with": "XMLHttpRequest",
             "content-type": "multipart/form-data; boundary=----WebKitFormBoundaryZpbAzm9jDM343NtB"
-    }
+        }
         re = self.r.post(self.base_url, params=data, headers=head)
         hh = re.text
         dic = json.loads(hh)
@@ -27,5 +27,7 @@ class VUFR:
         url = dic['data']['shorturl']
         if message == "Link has been shortened":
             return url
+        elif re.status_code == 429:
+            return "429: You are ratelimited."
         else:
             return "An error has occured: " + message
\ No newline at end of file
